==> haskell-annotated-wl-pprint-0.7.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: annotated-wl-pprint
version: 0.7.0
id: annotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
key: annotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
license: BSD3
maintainer: david@davidchristiansen.dk
homepage: https://github.com/david-christiansen/annotated-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.
category: Text
author: Daan Leijen, David Raymond Christiansen
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.Leijen
abi: f8eb6c4f7b932febcee0363cdc5fbd75
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/annotated-wl-pprint-0.7.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/annotated-wl-pprint-0.7.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/annotated-wl-pprint-0.7.0
hs-libraries: HSannotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-annotated-wl-pprint-0.7.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: annotated-wl-pprint
version: 0.7.0
id: annotated-wl-pprint-0.7.0-3FrdG13wTO5J8qYXtEBG3s
key: annotated-wl-pprint-0.7.0-3FrdG13wTO5J8qYXtEBG3s
license: BSD3
maintainer: david@davidchristiansen.dk
homepage: https://github.com/david-christiansen/annotated-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.
category: Text
author: Daan Leijen, David Raymond Christiansen
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.Leijen
abi: c4e3d2c89fff9e2b4f0c6665ad8c50ee
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/annotated-wl-pprint-0.7.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/annotated-wl-pprint-0.7.0
hs-libraries: HSannotated-wl-pprint-0.7.0-3FrdG13wTO5J8qYXtEBG3s
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
